import { Component, EventEmitter, Output, Input, HostListener, ElementRef, NgModule } from '@angular/core';
import * as moment_ from 'moment';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const moment = moment_;
class DatePickerComponent {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
        this.dropdown = false;
        this.today = new Date();
        this.selecteddateIntext = 'DD/MM/YYYY';
        this.selectedDateDisplayFormat = 'DD/MM/YYYY';
        this._mode = 'dropdown';
        this.selected = new EventEmitter();
        this.monthArr = [];
        this.week1 = [];
        this.week2 = [];
        this.week3 = [];
        this.week4 = [];
        this.week5 = [];
        this.week6 = [];
        this.monthNames = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
        this.weekNames = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
        this.today.setHours(0, 0, 0, 0);
        this.generateCurrent(this.today);
    }
    /**
     * @param {?} mode
     * @return {?}
     */
    set mode(mode) {
        this._mode = mode;
    }
    /**
     * @param {?} format
     * @return {?}
     */
    set format(format) {
        this.selectedDateDisplayFormat = format;
        if (this.selecteddate != null) {
            this.selecteddateIntext = moment(this.selecteddate).format(this.selectedDateDisplayFormat);
        }
        else {
            this.selecteddateIntext = format;
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} event
     * @return {?}
     */
    clickout(event) {
        if (!this.el.nativeElement.contains(event.target)) {
            this.dropdown = false;
        }
    }
    /**
     * @param {?} currentday
     * @return {?}
     */
    generateCurrent(currentday) {
        this.currentMonth = moment(currentday).month() + 1;
        this.currentMonthInWords = this.monthNames[this.currentMonth - 1];
        this.currentYear = moment(currentday).year();
        this.start = moment(currentday).startOf('month');
        this.end = moment(currentday).endOf('month').subtract(1, 'days');
        this.generateDaysOfMonth();
    }
    /**
     * @return {?}
     */
    generateDaysOfMonth() {
        let /** @type {?} */ start = this.start;
        const /** @type {?} */ end = this.end;
        this.monthArr = [];
        this.monthArr.push(this.createDateObj(start));
        while (start < end) {
            start = moment(start).add(1, 'days');
            let /** @type {?} */ dateobj = new DateObject();
            dateobj = this.createDateObj(start);
            this.monthArr.push(dateobj);
        }
        //  console.log(this.monthArr);
        this.generateWeeks();
    }
    /**
     * @param {?} start
     * @return {?}
     */
    createDateObj(start) {
        const /** @type {?} */ dateobj = new DateObject();
        dateobj.date = start.toDate();
        dateobj.weekDay = start.day();
        dateobj.day = start.date();
        dateobj.month = start.month();
        dateobj.year = start.year();
        return dateobj;
    }
    /**
     * @return {?}
     */
    generateWeeks() {
        this.weekObject = [];
        this.weekObject.push([null, null, null, null, null, null, null]);
        this.weekObject.push([null, null, null, null, null, null, null]);
        this.weekObject.push([null, null, null, null, null, null, null]);
        this.weekObject.push([null, null, null, null, null, null, null]);
        this.weekObject.push([null, null, null, null, null, null, null]);
        this.weekObject.push([null, null, null, null, null, null, null]);
        const /** @type {?} */ len = this.monthArr.length;
        let /** @type {?} */ i = 0;
        for (let /** @type {?} */ k = 0; k < len; k++) {
            const /** @type {?} */ day = this.monthArr[k].weekDay;
            if (day === 6) {
                this.weekObject[i][day] = this.monthArr[k];
                i++;
            }
            else {
                this.weekObject[i][day] = this.monthArr[k];
            }
        }
        console.log(this.weekObject);
    }
    /**
     * @return {?}
     */
    changeInYear() {
        this.start = moment(this.start).set('year', this.currentYear);
        this.generateCurrent(this.start);
    }
    /**
     * @return {?}
     */
    increaseMonth() {
        this.start = moment(this.start).add(1, 'month');
        this.generateCurrent(this.start);
    }
    /**
     * @return {?}
     */
    decreaseMonth() {
        this.start = moment(this.start).subtract(1, 'month');
        this.generateCurrent(this.start);
    }
    /**
     * @param {?} date
     * @return {?}
     */
    selectedDate(date) {
        this.selecteddate = date.date;
        this.selected.emit(this.selecteddate);
        this.selecteddateIntext = moment(date.date).format(this.selectedDateDisplayFormat);
        this.dropdown = false;
    }
    /**
     * @return {?}
     */
    toggle() {
        this.dropdown = !this.dropdown;
        console.log(this.dropdown);
    }
}
DatePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-date-picker',
                template: `
<div class="dropdown" *ngIf="_mode === 'dropdown'">
  <button (click)="toggle();" class="dropbtn" > {{selecteddateIntext}}</button>
    <div id="myDropdown" class="dropdown-content" [ngClass]="{'show':dropdown}">
      <div *ngIf="true; then datepicker" >
        
     </div>
    </div>
</div>

<div  *ngIf="_mode === 'inline'" >
        <div *ngIf="true; then datepicker" > </div>
</div>



  <ng-template #datepicker>
    <div style="width:325px;height:316px;">
      <div class="month">      
        <ul>
          <li class="prev" (click)="decreaseMonth();">&#10094;</li>
          <li class="next" (click)="increaseMonth();">&#10095;</li>
          <li>
            {{currentMonthInWords}}
            <span style="font-size:18px"><input type="number" min=0 max=3000 [(ngModel)]="currentYear" (change)="changeInYear()"></span>
          </li>
        </ul>
      </div>
      
      <ul class="weekdays">
        <li>Su</li>
        <li>Mo</li>
        <li>Tu</li>
        <li>We</li>
        <li>Th</li>
        <li>Fr</li>
        <li>Sa</li>
      </ul>
      
      <ul class="days">  
        
        <li *ngFor="let d of weekObject[0]" (click)="selectedDate(d);"><span [ngClass]=" d?.date - selecteddate === 0?'active':''" >{{d?.day}}</span></li>
        <li *ngFor="let d of weekObject[1]" (click)="selectedDate(d);"><span [ngClass]=" d?.date - selecteddate === 0?'active':''" >{{d?.day}}</span></li>
        <li *ngFor="let d of weekObject[2]" (click)="selectedDate(d);"><span [ngClass]=" d?.date - selecteddate === 0?'active':''" >{{d?.day}}</span></li>
        <li *ngFor="let d of weekObject[3]" (click)="selectedDate(d);"><span [ngClass]=" d?.date - selecteddate === 0?'active':''" >{{d?.day}}</span></li>
        <li *ngFor="let d of weekObject[4]" (click)="selectedDate(d);"><span [ngClass]=" d?.date - selecteddate === 0?'active':''" >{{d?.day}}</span></li>
        <li *ngFor="let d of weekObject[5]" (click)="selectedDate(d);"><span [ngClass]=" d?.date - selecteddate === 0?'active':''" >{{d?.day}}</span></li>
        <li *ngFor="let d of weekObject[6]" (click)="selectedDate(d);"><span [ngClass]=" d?.date - selecteddate === 0?'active':''" >{{d?.day}}</span></li>
      </ul>
      </div>
 </ng-template>`,
                styles: [`*{-webkit-box-sizing:border-box;box-sizing:border-box}ul{list-style-type:none;font-family:Arial,Helvetica,sans-serif}.month{padding:25px;width:100%;background:#85b7e2;text-align:center}.month ul{margin:0;padding:0}.month ul li{color:#fff;font-size:20px;letter-spacing:3px}.month .prev{float:left;cursor:pointer}.month .next{float:right;cursor:pointer}.weekdays{margin:0;padding:10px 0;background-color:#c2dbf0}.weekdays li{display:inline-block;width:12.6%;color:#102940;text-align:center}.days{padding:10px 0;background:#edf4fb;margin:0}.days li{list-style-type:none;display:inline-block;width:13.6%;text-align:center;margin-bottom:5px;font-size:12px;color:#102940;cursor:pointer}.days li .active{padding:5px;background:#85b7e2;color:#fff!important}@media screen and (max-width:720px){.days li,.weekdays li{width:13.1%}}@media screen and (max-width:420px){.days li,.weekdays li{width:12.5%}.days li .active{padding:2px}}@media screen and (max-width:290px){.days li,.weekdays li{width:12.2%}}input[type=number]{padding:0;margin:8px 0;background:0 0;border:none;color:#fff;font-size:18px;text-align:center}.dropbtn{background-color:#3498db;color:#fff;padding:16px;font-size:16px;border:none;cursor:pointer}.dropbtn:focus,.dropbtn:hover{background-color:#2980b9}.dropdown{position:relative;display:inline-block}.dropdown-content{display:none;position:absolute;background-color:#f1f1f1;min-width:160px;overflow:auto;-webkit-box-shadow:0 8px 16px 0 rgba(0,0,0,.2);box-shadow:0 8px 16px 0 rgba(0,0,0,.2);z-index:1}.dropdown-content a{color:#000;padding:12px 16px;text-decoration:none;display:block}.dropdown a:hover{background-color:#ddd}.show{display:block!important}`]
            },] },
];
/** @nocollapse */
DatePickerComponent.ctorParameters = () => [
    { type: ElementRef, },
];
DatePickerComponent.propDecorators = {
    "mode": [{ type: Input, args: ['mode',] },],
    "format": [{ type: Input, args: ['format',] },],
    "selected": [{ type: Output },],
    "clickout": [{ type: HostListener, args: ['document:click', ['$event'],] },],
};
class DateObject {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NgxDatePickerModule {
}
NgxDatePickerModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule, FormsModule
                ],
                declarations: [DatePickerComponent],
                exports: [
                    DatePickerComponent
                ]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { NgxDatePickerModule, DatePickerComponent as ɵa };
//# sourceMappingURL=ngx-date-picker-component.js.map
